rename COFFMCAsmInfo -> MCAsmInfoCOFF, likewise for darwin.


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@79773 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Target/PowerPC/PPCMCAsmInfo.cpp b/lib/Target/PowerPC/PPCMCAsmInfo.cpp
index c9ff842..c87879b 100644
--- a/lib/Target/PowerPC/PPCMCAsmInfo.cpp
+++ b/lib/Target/PowerPC/PPCMCAsmInfo.cpp
@@ -7,14 +7,14 @@
 //
 //===----------------------------------------------------------------------===//
 //
-// This file contains the declarations of the DarwinMCAsmInfo properties.
+// This file contains the declarations of the MCAsmInfoDarwin properties.
 //
 //===----------------------------------------------------------------------===//
 
 #include "PPCMCAsmInfo.h"
 using namespace llvm;
 
-PPCDarwinMCAsmInfo::PPCDarwinMCAsmInfo(bool is64Bit) {
+PPCMCAsmInfoDarwin::PPCMCAsmInfoDarwin(bool is64Bit) {
   PCSymbol = ".";
   CommentString = ";";
   ExceptionsType = ExceptionHandling::Dwarf;
diff --git a/lib/Target/PowerPC/PPCTargetMachine.cpp b/lib/Target/PowerPC/PPCTargetMachine.cpp
index de3a3d0..3371954 100644
--- a/lib/Target/PowerPC/PPCTargetMachine.cpp
+++ b/lib/Target/PowerPC/PPCTargetMachine.cpp
@@ -25,7 +25,7 @@
   Triple TheTriple(TT);
   bool isPPC64 = TheTriple.getArch() == Triple::ppc64;
   if (TheTriple.getOS() == Triple::Darwin)
-    return new PPCDarwinMCAsmInfo(isPPC64);
+    return new PPCMCAsmInfoDarwin(isPPC64);
   return new PPCLinuxMCAsmInfo(isPPC64);
   
 }
diff --git a/lib/Target/PowerPC/PPCMCAsmInfo.h b/lib/Target/PowerPC/PPCMCAsmInfo.h
index 3f5118b..96ae6fb 100644
--- a/lib/Target/PowerPC/PPCMCAsmInfo.h
+++ b/lib/Target/PowerPC/PPCMCAsmInfo.h
@@ -7,7 +7,7 @@
 //
 //===----------------------------------------------------------------------===//
 //
 // This file contains the declaration of the DarwinMCAsmInfo class.
 //
 //===----------------------------------------------------------------------===//
 
@@ -18,8 +18,8 @@
 
 namespace llvm {
 
-  struct PPCDarwinMCAsmInfo : public DarwinMCAsmInfo {
-    explicit PPCDarwinMCAsmInfo(bool is64Bit);
+  struct PPCMCAsmInfoDarwin : public MCAsmInfoDarwin {
+    explicit PPCMCAsmInfoDarwin(bool is64Bit);
   };
 
   struct PPCLinuxMCAsmInfo : public MCAsmInfo {
@@ -7,7 +7,7 @@
 //===----------------------------------------------------------------------===//
 //
-// This file contains the declaration of the DarwinMCAsmInfo class.
+// This file contains the declaration of the MCAsmInfoDarwin class.
 //
 //===----------------------------------------------------------------------===//